LoadingConfiguration class

Constructors

LoadingConfiguration({required LoadingAnimationStyle style, required Duration duration, List<TweenSequenceItem<double>> initialTweenSequenceItems = const [], int delayStart = 200})
const

Properties

delayStart → int
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
initialTweenSequenceItems → List<TweenSequenceItem<double>>
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
style → LoadingAnimationStyle
final
tweenSequenceItems → List<TweenSequenceItem<double>>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

style1 → const LoadingConfiguration