MenuBoardConfiguration<T> class

Constructors

const

Properties

childRadius → double
childRadius will be verify again
final
decorationBuilder → BoxDecorationBuilder<T>?
final
hashCode → int
The hash code for this object.
no setterinherited
isDebug → bool
will enable world.drawDebugData
final
itemPadding → EdgeInsets
final
loadingAnimationStyle → LoadingAnimationStyle
no setter
loadingConfiguration → LoadingConfiguration
final
parentRadius → double
parentRadius will be prioritized.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space → double
space between parent and child
final
startAnimationAfterRotation → bool
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → MenuMorphType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited