MenuState<T> class

Constructors

Properties

children → List<MenuItem<T>>
no setter
childrenBox → Map<int, MenuItemBox2D>
final
hasData → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
initialData → MenuBoardData<T>?
if you are waiting for fetching data from BE initialData must be null then animation will be start automatically when you have data, please call updateMenuBoardData
final
parent → MenuItem<T>?
no setter
parentBox → MenuItemBox2D
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableChildren([List<int> indexes = const []]) → void
if indexes is empty -> apply for all children
disableParent() → void
enableChildren([List<int> indexes = const []]) → void
if indexes is empty -> apply for all children
enableParent() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateItemPositions(Vector2 parentPosition, List<Vector2> childrenPositions, [double? parentRadius, double? childRadius]) → MenuState<T>
updateMenuBoardData(MenuBoardData<T> data) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited