MenuBoardData<T> class

Constructors

const

Properties

children → List<MenuItem<T>>
final
hashCode → int
The hash code for this object.
no setterinherited
parent → MenuItem<T>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableChildren([List<int> indexes = const []]) → MenuBoardData<T>
if indexes is empty -> apply for all children
disableParent() → MenuBoardData<T>
enableChildren([List<int> indexes = const []]) → MenuBoardData<T>
if indexes is empty -> apply for all children
enableParent() → MenuBoardData<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
updateChildren(List<MenuItem<T>> children) → MenuBoardData<T>
updateParent(MenuItem<T> parent) → MenuBoardData<T>

Operators

operator ==(Object other) → bool
The equality operator.
inherited