MenuItemBox2D class

Constructors

factory

Properties

body → Body
final
collided ← bool
no getter
collisionSpeed → double
final
currentPosition → Offset
no setter
globalKey ↔ GlobalKey<BaseDraggableItemState>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAtOriginPosition → bool
no setter
isCollided → bool
no setter
isPrioritized → bool
true -> user is moving the item a
no setter
originPosition → Vector2
final
prioritized ← bool
no getter
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double
final

Methods

checkCurrentPositionAndStop() → void
collidedWithTheOther(Vector2 direction, [Duration duration = Durations.medium3]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPanEnd() → void
onPanStart() → void
onPanUpdate(Offset offset) → void
stopShakeAnimation() → void
toString() → String
A string representation of this object.
override
updatePositionAndRadius(Vector2 position, [double? radius]) → MenuItemBox2D
for device orientation it will update originPosition and body.position

Operators

operator ==(Object other) → bool
The equality operator.
inherited