MenuBoardConfiguration<T> class
Constructors
-
MenuBoardConfiguration({required MenuMorphType type, required double parentRadius, required double childRadius, LoadingConfiguration loadingConfiguration = LoadingConfiguration.style1, double space = 12.0, bool startAnimationAfterRotation = false, BoxDecorationBuilder<
T> ? decorationBuilder, EdgeInsets itemPadding = const EdgeInsets.all(8.0), bool isDebug = false}) -
const
Properties
- childRadius → double
-
childRadius will be verify again
final
-
decorationBuilder
→ BoxDecorationBuilder<
T> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDebug → bool
-
will enable
world.drawDebugDatafinal - itemPadding → EdgeInsets
-
final
- loadingAnimationStyle → LoadingAnimationStyle
-
no setter
- loadingConfiguration → LoadingConfiguration
-
final
- parentRadius → double
-
parentRadius will be prioritized.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- space → double
-
space between parent and child
final
- startAnimationAfterRotation → bool
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → MenuMorphType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited